==> reaction-2.2.9.tgz: package/es6/element/virtualDOMNode/element.js <==
'use strict';

const VirtualDOMNode = require('../virtualDOMNode'),
      virtualDOMElementMixins = require('../../mixins/virtualDOMElement');

class VirtualDOMElement extends VirtualDOMNode {
  mount(parent, reference, context) {
    super.mount(parent, reference);

    const childParent = this,
          childReference = null,
          childContext = context,
          children = this.getChildren();

    children.forEach(function(child) {
      child.mount(childParent, childReference, childContext);
    });

    this.applyProps();
  }

  unmount(context) {
    const childContext = context,
          children = this.getChildren();

    children.forEach(function(child) {
      child.unmount(childContext);
    });

    super.unmount();
  }

  applyProps() {
    const names = Object.keys(this.props);

    names.forEach(function(name) {
      const value = this.props[name];

      if (false) {

      } else if (this.isHandlerName(name)) {
        this.setHandler(name, value);
      } else if (this.isAttributeName(name)) {
        this.setAttribute(name, value);
      } else if (name === 'ref') {
        const callback = value; ///
        
        callback(this.domElement);
      }
    }.bind(this));
  }

  setHandler(name, value) {
    const eventType = name.substr(2).toLowerCase(), ///
          handler = value;  ///

    this.domElement.addEventListener(eventType,  handler);
  }

	isHandlerName(name) {
		return name.match(/^on/);
	}
}

Object.assign(VirtualDOMElement.prototype, virtualDOMElementMixins);

module.exports = VirtualDOMElement;

==> reaction-2.2.13.tgz: package/es6/element/virtualDOMNode/element.js <==
'use strict';

const VirtualDOMNode = require('../virtualDOMNode'),
      virtualDOMElementMixins = require('../../mixins/virtualDOMElement');

class VirtualDOMElement extends VirtualDOMNode {
  mount(parent, reference, context) {
    super.mount(parent, reference);

    const childParent = this,
          childReference = null,
          childContext = context,
          children = this.getChildren();

    children.forEach((child) => child.mount(childParent, childReference, childContext));

    this.applyProps();
  }

  unmount(context) {
    const childContext = context,
          children = this.getChildren();

    children.forEach((child) => child.unmount(childContext));

    super.unmount();
  }

  applyProps() {
    const names = Object.keys(this.props);

    names.forEach((name) => {
      const value = this.props[name];

      if (false) {

      } else if (this.isHandlerName(name)) {
        this.setHandler(name, value);
      } else if (this.isAttributeName(name)) {
        this.setAttribute(name, value);
      } else if (name === 'ref') {
        const callback = value; ///
        
        callback(this.domElement);
      }
    });
  }

  setHandler(name, value) {
    const eventType = name.substr(2).toLowerCase(), ///
          handler = value;  ///

    this.domElement.addEventListener(eventType,  handler);
  }

	isHandlerName(name) {
		return name.match(/^on/);
	}
}

Object.assign(VirtualDOMElement.prototype, virtualDOMElementMixins);

module.exports = VirtualDOMElement;
